/*
* phone.c - example of phone for media volume control.
* This file is part of PetrSU KP Library.
*
* Copyright (C) 2009 - Vanag Pavel. All rights reserved.
*
* PetrSU KP Library is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* PetrSU KP Library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with PetrSU KP Library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor,
* Boston, MA  02110-1301  USA
*/

#include "../SmartSlog_lib/media.h"


static void print_menu()
{
	printf("\n--- Menu ---");
	printf("\n1 - Call incoming.");
	printf("\n2 - Call ends.");
	printf("\n0 - Exit.\n");
}


static void clean_ss()
{
	printf("\n\n --- Clean ---\n");

	ss_triple_t *triple_rqst = NULL;
	ss_add_triple(&triple_rqst, SS_RDF_SIB_ANY, SS_RDF_SIB_ANY, SS_RDF_SIB_ANY, SS_RDF_TYPE_URI, SS_RDF_TYPE_LIT);

	ss_triple_t *triple_res1 = NULL;
	if(ss_query(get_ss_info(), triple_rqst, &triple_res1) < 0) {
		ss_delete_triples(triple_rqst);
		return;
	}

        ss_delete_triples(triple_rqst);
	triple_rqst = NULL;

	ss_add_triple(&triple_rqst, SS_RDF_SIB_ANY, RDF_TYPE, SS_RDF_SIB_ANY, SS_RDF_TYPE_URI, SS_RDF_TYPE_URI);

	ss_triple_t *triple_res2 = NULL;
	if(ss_query(get_ss_info(), triple_rqst, &triple_res2) < 0) {
		ss_delete_triples(triple_rqst);
		return;
	}

        concat_triplets(triple_res1, triple_res2);

	ss_delete_triples(triple_rqst);
	triple_rqst = NULL;

	ss_remove(get_ss_info(), triple_res1);
	ss_delete_triples(triple_res1);
}

int main()
{
	init_ss();
	register_ontology();

	if (ss_join(get_ss_info(), "Phone KP") == -1) {
		printf("Can't join to SS\n");
		return 0;
	}


        individual_t *phone = new_individual(CLASS_MOBILEPHONE);

	if (phone == NULL) {
		printf("\nError: %s\n", get_error_text());
		return 0;
	}


        init_individual_with_uuid(phone, "phone1");

	char *calling = (char *) malloc(sizeof(char) * 2);
	calling[0] = '0';
	calling[1] = '\0';
	set_property_by_name(phone, PROPERTY_ISCALLING->name, strdup(calling));

	while (true) {
		print_menu();

		char c = getc(stdin);

		if (c == '0') {
			break;
		} else if (c == '1') {
			char *old_val = strdup(calling);
			calling[0] = '1';
			if (ss_update_property_with_data(phone, PROPERTY_ISCALLING->name, old_val, strdup(calling)) < 0)
				printf("Values coudn't updated\n");
			free(old_val);
		} else if (c == '2') {
			char *old_val = strdup(calling);
			calling[0] = '0';
			if (ss_update_property_with_data(phone, PROPERTY_ISCALLING->name, old_val, strdup(calling)) < 0)
				printf("Values coudn't updated\n");
			free(old_val);
		}
	}



        clean_ss();

	free(calling);
	free_individual(phone);
	free_class(CLASS_MOBILEPHONE);

	ss_leave(get_ss_info());

	return 0;
}
