/*
* player.c - example of player for media volume control.
* This file is part of PetrSU KP Library.
*
* Copyright (C) 2009 - Vanag Pavel. All rights reserved.
*
* PetrSU KP Library is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* PetrSU KP Library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with PetrSU KP Library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor,
* Boston, MA  02110-1301  USA
*/

#include "../SmartSlog_lib/media.h"


int main(int argc, char **argv)
{
	init_ss();
	register_ontology();

	if (ss_join(get_ss_info(), "Player KP") == -1) {
		printf("Can't join to SS\n");
		return 0;
	}

        individual_t *phone = new_individual(CLASS_MOBILEPHONE);

	if (phone == NULL) {
		printf("\nError: %s\n", get_error_text());
		return 0;
	}

        if (argc < 2)
		phone->uuid = "phone1";
	else
		phone->uuid = argv[1];

	if (argc >= 3)
		PROPERTY_ISCALLING->name = argv[2];

	property_t *property = (property_t *) get_property_type(CLASS_MOBILEPHONE, PROPERTY_ISCALLING->name);

	if (property == NULL) {
		return 0;
	}

        subscription_container_t *conatiner = new_subscription_container();

	list_t *properties = list_get_new_list();
	list_add_data(property, properties);

	add_individual_to_subscription_container(conatiner, phone, properties);

	if (ss_subscribe_container(conatiner, false) != 0) {
		printf("\nCan't subscribe\n");
		return 0;
	}

	char *old_val = NULL;
	while (true) {
		const prop_val_t *p_val = get_property(phone, PROPERTY_ISCALLING->name);

		if (p_val != NULL) {
			char *new_val = strdup((char *) p_val->prop_value);
			if (old_val == NULL) old_val = new_val;

			if ((new_val[0]=='0') && (old_val[0]=='1'))
				printf("\n -------- Volume UP\n");
			else if ((new_val[0]=='1') && (old_val[0]=='0'))
				printf("\n -------- Volume DOWN\n");

			old_val = new_val;
			printf("\n");
			fflush(stdout);
		}
	        wait_subscribe(conatiner);
	}

        sleep(5);
	printf("\nLive = %i %i", ss_leave(get_ss_info()), get_ss_info()->ss_errno);

	return 0;
	}
